### Description
This repository contains code to make datasets stored on th corpora network drive of the chair compatible with the [tensorflow dataset api](https://www.tensorflow.org/api_docs/python/tf/data/Dataset) .

### Currently available Models

#### Image Models

| Model       | Status        | Pretrained  | Url
| :------------- |:-------------:| :-------------:| :-----|
| EfficientNetB0      | ✅              | ❌  | https://keras.io/api/applications/ |
| EfficientNetB1      | ✅              | ❌ | https://keras.io/api/applications/ |
| EfficientNetB2      | ✅              | ❌ | https://keras.io/api/applications/ |
| EfficientNetB3      | ✅              | ❌ | https://keras.io/api/applications/ |
| EfficientNetB4      | ✅              | ❌ | https://keras.io/api/applications/ |
| EfficientNetB5      | ✅              | ❌ | https://keras.io/api/applications/ |
| EfficientNetB6      | ✅              | ❌ | https://keras.io/api/applications/ |
| EfficientNetB7      | ✅              | ❌ | https://keras.io/api/applications/ |


